# Ratio Studies

|| |
|-|--|
| Locality | {{locality}} |
| Valuation date | {{val_date}} |
| Model group | {{model_group}} |  
| Study period | {{sales_back_to_date}} - {{val_date}} |

## Executive Summary

Ratio studies are the primary tool for evaluating the *accuracy* of mass appraisal predictions. The IAAO defines the standards for these in its [Standard on Ratio Studies](https://www.iaao.org/wp-content/uploads/Standard_on_Ratio_Studies.pdf).

We perform IAAO-standard ratio studies for all model groups, but we  go beyond that with additional relevant statistics, as well as detailed breakdowns by property type, location, price tier, and other relevant factors.

### Overall results

The following table provides overall results for the entire locality for the {{model_group}} model group.

{{overall_results}}

## Breakdowns

The following tables provide detailed breakdowns of the results by various factors, comparing results for {{locality}} with our own.

### {{locality}} results

{{locality_results}}

### Our results

{{modeler_results}}


